==> nextcloud-27.1.7p0.tgz: nextcloud/apps/logreader/l10n/nb.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logging",
    "Errors in the log" : "Feil i loggen",
    "No errors in the logs since %s" : "Ingen feil i loggene siden %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n feil i loggene siden %s","%n feil i loggene siden %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advarsel i loggene siden %s","%n advarsler i loggene siden %s"],
    "Log Reader" : "Loggleser",
    "A log reader for Nextcloud" : "En loggleser for Nextcloud",
    "Log reader for Nextcloud" : "Loggleser for Nextcloud",
    "Log reader" : "Loggleser",
    "Open log reader settings" : "Åpne innstillinger for loggleser",
    "Log reader settings" : "Innstillinger for loggleser",
    "Currently the log file {file} is shown" : "For øyeblikket vises loggfilen {file}",
    "Show server log" : "Vis serverlogg",
    "Live view is disabled" : "Direktevisning er deaktivert",
    "No log file" : "Ingen loggfil",
    "File-based logging must be enabled to access logs from the Web UI." : "Filbasert logging må være aktivert for å få tilgang til logger fra webgrensesnittet.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Hvis du føler at dette er en feil, må du kontrollere {setting} i {config} og sjekke Nextcloud Administration Manual.",
    "Level" : "Nivå",
    "App" : "App",
    "No app in context" : "Ingen app i konteksten",
    "Time" : "Tid",
    "Copy raw entry" : "Kopier rå oppføring",
    "Copy formatted entry" : "Kopier formatert oppføring",
    "Hide exception details" : "Skjul unntaksdetaljer",
    "View exception details" : "Vis unntaksdetaljer",
    "Raw log entry" : "Rå loggoppføring",
    "Log entry successfully copied" : "Loggoppføring kopiert",
    "Search log entries" : "Søk i loggoppføringer",
    "Caused by {exception}" : "Forårsaket av {exception}",
    "Line {line}" : "Linje {line}",
    "Filter log levels" : "Filtrer loggnivåer",
    "Set log level" : "Angi loggnivå",
    "Time format" : "Tidsformat",
    "Live view" : "Direkte visning",
    "Download/Upload logs" : "Last ned/opp logger",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Du kan også vise loggoppføringer kopiert fra utklippstavlen ved å lime dem inn i loggvisningen ved hjelp av: {keyboardShortcut}",
    "Download logs" : "Last ned logger",
    "Show local log file" : "Vis lokal loggfil",
    "Upload local log file to be displayed" : "Last opp lokal loggfil som skal vises",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Kunne ikke analysere lokal loggfil",
    "Raw data" : "Rå data",
    "Local time" : "Lokal tid",
    "UTC time" : "UTC-tid",
    "Time format used for displaying the timestamp" : "Tidsformat som brukes til å vise tidsstempelet",
    "(Local log files only support the \"raw\" time format)" : "(Lokale loggfiler støtter bare det \"rå\" tidsformatet)",
    "Could not change date time format." : "Kunne ikke endre dato/tid-formatet.",
    "Polling is disabled because server is not configured to log to file" : "Avspørring er deaktivert fordi serveren ikke er konfigurert til å logge til fil",
    "Polling (live view)" : "Avspørring (direkte visning)",
    "Could not change live view setting." : "Kunne ikke endre innstilling for direkte visning.",
    "Filter logging levels" : "Filtrer loggingsnivåer",
    "Could not set logging levels to show" : "Kan ikke angi at loggingsnivåer skal vises",
    "Set backend loglevel" : "Angi loggnivå for backend",
    "Could not set logging level" : "Kan ikke angi loggingsnivå",
    "Application" : "Applikasjon",
    "Message" : "Melding",
    "Log entry actions" : "Handlinger for loggoppføring",
    "Loading older log entries" : "Laster inn eldre loggoppføringer",
    "No older log entries available" : "Ingen eldre loggoppføringer tilgjengelig",
    "Collapse row" : "Skjul rad",
    "Expand row" : "Utvid rad",
    "Show details" : "Vis detaljer",
    "Debug" : "Feilsøk",
    "Info" : "Info",
    "Warning" : "Advarsel",
    "Error" : "Feil",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Kunne ikke laste loggoppføringer",
    "Clipboard" : "Utklippstavle",
    "Could not parse clipboard content" : "Kunne ikke analysere innholdet på utklippstavlen",
    "Could not fetch new log entries (server unavailable)" : "Kan ikke hente nye loggoppføringer (server utilgjengelig)",
    "Could not fetch new entries" : "Kunne ikke hente nye oppføringer",
    "Could not copy to clipboard, please copy manually:" : "Kunne ikke kopiere til utklippstavlen, vennligst kopier manuelt:",
    "\tfrom {address} by {user} at {time}\n" : "\tfra {address} av {user} kl. {time}\n",
    "Error parsing log" : "Feil ved fortolkning av logg",
    "Caused by " : "Forårsaket av",
    "Copy" : "Kopier",
    "Copy raw" : "Kopier rå",
    "Copy formatted" : "Kopier formatert",
    "No server logs" : "Ingen serverlogger",
    "One or more entries are hidden by the log level filter" : "Én eller flere oppføringer er skjult av loggnivåfilteret",
    "Everything is working fine" : "Alt fungerer fint",
    "Load log file" : "Last inn loggfil",
    "Invalid log file" : "Ugyldig loggfil",
    "Log levels" : "Loggfør nivå",
    "Log content" : "Loggfør innhold",
    "Live update" : "Levende oppdatering",
    "line {line}" : "linje {line}",
    "Download / Upload logs" : "Last ned / last opp logger"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/logreader/l10n/nb.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logging",
    "Errors in the log" : "Feil i loggen",
    "Failed to get an iterator for log entries: %s" : "Kan ikke få en iterator for loggoppføringer: %s",
    "No errors in the logs since %s" : "Ingen feil i loggene siden %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n feil i loggene siden %s","%n feil i loggene siden %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advarsel i loggene siden %s","%n advarsler i loggene siden %s"],
    "Log Reader" : "Loggleser",
    "A log reader for Nextcloud" : "En loggleser for Nextcloud",
    "Log reader for Nextcloud" : "Loggleser for Nextcloud",
    "Log reader" : "Loggleser",
    "Open log reader settings" : "Åpne innstillinger for loggleser",
    "Log reader settings" : "Innstillinger for loggleser",
    "Currently the log file {file} is shown" : "For øyeblikket vises loggfilen {file}",
    "Show server log" : "Vis serverlogg",
    "Live view is disabled" : "Direktevisning er deaktivert",
    "No log file" : "Ingen loggfil",
    "File-based logging must be enabled to access logs from the Web UI." : "Filbasert logging må være aktivert for å få tilgang til logger fra webgrensesnittet.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Hvis du føler at dette er en feil, må du kontrollere {setting} i {config} og sjekke Nextcloud Administration Manual.",
    "Level" : "Nivå",
    "App" : "App",
    "No app in context" : "Ingen app i konteksten",
    "Time" : "Tid",
    "Copy raw entry" : "Kopier rå oppføring",
    "Copy formatted entry" : "Kopier formatert oppføring",
    "Hide exception details" : "Skjul unntaksdetaljer",
    "View exception details" : "Vis unntaksdetaljer",
    "Raw log entry" : "Rå loggoppføring",
    "Log entry successfully copied" : "Loggoppføring kopiert",
    "Search log entries" : "Søk i loggoppføringer",
    "Caused by {exception}" : "Forårsaket av {exception}",
    "Line {line}" : "Linje {line}",
    "Filter log levels" : "Filtrer loggnivåer",
    "Set log level" : "Angi loggnivå",
    "Time format" : "Tidsformat",
    "Live view" : "Direkte visning",
    "Download/Upload logs" : "Last ned/opp logger",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Du kan også vise loggoppføringer kopiert fra utklippstavlen ved å lime dem inn i loggvisningen ved hjelp av: {keyboardShortcut}",
    "Download logs" : "Last ned logger",
    "Show local log file" : "Vis lokal loggfil",
    "Upload local log file to be displayed" : "Last opp lokal loggfil som skal vises",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Kunne ikke analysere lokal loggfil",
    "Raw data" : "Rå data",
    "Local time" : "Lokal tid",
    "UTC time" : "UTC-tid",
    "Relative" : "Relativ",
    "Time format used for displaying the timestamp" : "Tidsformat som brukes til å vise tidsstempelet",
    "(Local log files only support the \"raw\" time format)" : "(Lokale loggfiler støtter bare det \"rå\" tidsformatet)",
    "Could not change date time format." : "Kunne ikke endre dato/tid-formatet.",
    "Polling is disabled because server is not configured to log to file" : "Avspørring er deaktivert fordi serveren ikke er konfigurert til å logge til fil",
    "Polling (live view)" : "Avspørring (direkte visning)",
    "Could not change live view setting." : "Kunne ikke endre innstilling for direkte visning.",
    "Filter logging levels" : "Filtrer loggingsnivåer",
    "Could not set logging levels to show" : "Kan ikke angi at loggingsnivåer skal vises",
    "Set backend loglevel" : "Angi loggnivå for backend",
    "Could not set logging level" : "Kan ikke angi loggingsnivå",
    "Application" : "Applikasjon",
    "Message" : "Melding",
    "Log entry actions" : "Handlinger for loggoppføring",
    "Loading older log entries" : "Laster inn eldre loggoppføringer",
    "No older log entries available" : "Ingen eldre loggoppføringer tilgjengelig",
    "Collapse row" : "Skjul rad",
    "Expand row" : "Utvid rad",
    "Show details" : "Vis detaljer",
    "Debug" : "Feilsøk",
    "Info" : "Info",
    "Warning" : "Advarsel",
    "Error" : "Feil",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Kunne ikke laste loggoppføringer",
    "Clipboard" : "Utklippstavle",
    "Could not parse clipboard content" : "Kunne ikke analysere innholdet på utklippstavlen",
    "Could not fetch new log entries (server unavailable)" : "Kan ikke hente nye loggoppføringer (server utilgjengelig)",
    "Could not fetch new entries" : "Kunne ikke hente nye oppføringer",
    "Could not copy to clipboard, please copy manually:" : "Kunne ikke kopiere til utklippstavlen, vennligst kopier manuelt:",
    "\tfrom {address} by {user} at {time}\n" : "\tfra {address} av {user} kl. {time}\n",
    "Error parsing log" : "Feil ved fortolkning av logg",
    "Caused by " : "Forårsaket av",
    "Copy" : "Kopier",
    "Copy raw" : "Kopier rå",
    "Copy formatted" : "Kopier formatert",
    "No server logs" : "Ingen serverlogger",
    "One or more entries are hidden by the log level filter" : "Én eller flere oppføringer er skjult av loggnivåfilteret",
    "Everything is working fine" : "Alt fungerer fint",
    "Load log file" : "Last inn loggfil",
    "Invalid log file" : "Ugyldig loggfil",
    "Log levels" : "Loggfør nivå",
    "Log content" : "Loggfør innhold",
    "Live update" : "Levende oppdatering",
    "line {line}" : "linje {line}",
    "Download / Upload logs" : "Last ned / last opp logger"
},
"nplurals=2; plural=(n != 1);");
